==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/pt-br/lang.php <==
<?php
/**
 * Brazilian Portuguese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author    Luis Fernando Enciso <lfenciso@certto.com.br>
 * @author    Alauton/Loug
 */
$lang['encoding']     = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']     = 'Editar';
$lang['btn_source']   = 'Ver código fonte';
$lang['btn_show']     = 'Ver entrada';
$lang['btn_create']   = 'Criar entrada';
$lang['btn_search']   = 'Pesquisar';
$lang['btn_save']     = 'Salvar';
$lang['btn_preview']  = 'Pré-visualizar';
$lang['btn_top']      = 'Voltar ao topo';
$lang['btn_newer']  = '<< mais recente';
$lang['btn_older']  = 'menos recente >>';
$lang['btn_revs']     = 'Revisões';
$lang['btn_recent']   = 'Alterações recentes';
$lang['btn_upload']   = 'Upload';
$lang['btn_cancel']   = 'Cancelar';
$lang['btn_index']    = 'Índice';
$lang['btn_secedit']  = 'Editar';
$lang['btn_login']    = 'Login';
$lang['btn_logout']   = 'Sair';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Atualizar';
$lang['btn_delete'] = 'Deletar';
$lang['btn_back']   = 'Voltar';

$lang['loggedinas']   = 'Usuário';
$lang['user']         = 'Usuário';
$lang['pass']         = 'Senha';
$pass['passchk']    = 'novamente';
$lang['remember']     = 'Lembrar';
$lang['fullname']     = 'Nome completo';
$lang['email']        = 'E-mail';
$lang['register']     = 'Registrar-se';
$lang['badlogin']     = 'Nome de usuário ou senha inválida.';

$lang['regmissing']   = 'Por favor, preencha todos os campos.';
$lang['reguexists']   = 'Este usuário já está registrado. Por favor, escolha outro nome de usuário.';
$lang['regsuccess']   = 'O usuário foi criado. A senha será enviada para o e-mail usado na inscrição.';
$lang['regsuccess2']= 'O usuário foi criado.';
$lang['regmailfail']  = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
$lang['regbadmail']   = 'O endereço de e-mail é inválido. Se o endereço está correto, e isto é um erro, por favor, contacte o administrador!';
$lang['regbadpass'] = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
$lang['regpwmail']    = 'A sua senha DokuWiki';
$lang['reghere']      = 'Não tem uma conta? Para registrar-se, acesse';

$lang['txt_upload']   = 'Escolha o arquivo para upload';
$lang['txt_filename'] = 'Insira o nome wiki (opcional)';
$lang['txt_overwrt']  = 'Substituir arquivo existente';
$lang['lockedby']     = 'Atualmente bloqueado por';
$lang['lockexpire']   = 'O bloqueio expira em';
$lang['willexpire']   = 'O bloqueio de edição para este documento irá expirar num minuto.\nPara evitar conflitos de edição, clique no botão <Pré-visualização> para reiniciar o temporizador de bloqueio.';

$lang['notsavedyet']  = 'Existem alterações não gravadas, que serão perdidas se continuar.\nDeseja realmente continuar?';
$lang['rssfailed']    = 'Ocorreu um erro neste canal RSS: ';
$lang['nothingfound'] = 'Nada foi encontrado.';

$lang['mediaselect']  = 'Selecionar arquivos';
$lang['fileupload']   = 'Upload de arquivo';
$lang['uploadsucc']   = 'Upload feito com sucesso';
$lang['uploadfail']   = 'Falha no upload. Talvez por não ter permissões?';
$lang['uploadwrong']  = 'Upload negado. Esta extensão de arquivo está proibida.';
$lang['uploadexist'] = 'O arquivo já existe. Nada foi feito.';
$lang['namespaces']   = 'Prefixos';
$lang['mediafiles']   = 'Arquivos disponíveis em';

$lang['hits']         = 'Resultados';
$lang['quickhits']    = 'Entradas encontradas';
$lang['toc']          = 'Tabela de Conteúdos';
$lang['current']      = 'Atual';
$lang['yours']        = 'A sua versão';
$lang['diff']         = 'mostrar diferenças com a versão atual';
$lang['line']         = 'Linha';
$lang['breadcrumb']   = 'Visitou';
$lang['lastmod']      = 'Modificado em';
$lang['by']         = 'por';
$lang['deleted']      = 'removido';
$lang['created']      = 'criado';
$lang['restored']     = 'Versão anterior restaurada.';
$lang['summary']      = 'Sumário da Edição';

$lang['mail_newpage'] = 'página adicionada:';
$lang['mail_changed'] = 'página modificada:';

$lang['nosmblinks']   = 'Links para pastas Windows partilhadas apenas funcionam com o Microsoft Internet Explorer.\nPode, no entanto, copiar e colar o link.';

$lang['qb_alert']     = 'Por favor, insira o texto que deseja formatar.\nSerá acrescentado ao fim do documento.';
$lang['qb_bold']      = 'Negrito';
$lang['qb_italic']    = 'Itálico';
$lang['qb_underl']    = 'Sublinhado';
$lang['qb_code']      = 'Código';
$lang['qb_strike']  = 'Texto Riscado';
$lang['qb_h1']        = 'Cabeçalho Nível 1';
$lang['qb_h2']        = 'Cabeçalho Nível 2';
$lang['qb_h3']        = 'Cabeçalho Nível 3';
$lang['qb_h4']        = 'Cabeçalho Nível 4';
$lang['qb_h5']        = 'Cabeçalho Nível 5';
$lang['qb_link']      = 'Link Interno';
$lang['qb_extlink']   = 'Link Externo';
$lang['qb_hr']        = 'Barra Horizontal';
$lang['qb_ol']        = 'Item numa Lista Ordenada';
$lang['qb_ul']        = 'Item numa Lista Não Ordenada';
$lang['qb_media']     = 'Incluir imagens e/ou outros arquivos';
$lang['qb_sig']       = 'Inserir Assinatura';

$lang['del_confirm']= 'Deletar esta entrada?';

$lang['admin_acl']  = 'Administrar a Lista de Controles de Acesso...';
$lang['admin_register']= 'Adicionar novo usuário...';

$lang['acl_group']  = 'Grupo';
$lang['acl_user']   = 'Usuário';
$lang['acl_perms']  = 'Permissões para';
$lang['page']       = 'Página';
$lang['namespace']  = 'Prefixo';

$lang['acl_perm1']  = 'Ler';
$lang['acl_perm2']  = 'Editar';
$lang['acl_perm4']  = 'Criar';
$lang['acl_perm8']  = 'Upload';
$lang['acl_perm16'] = 'Deletar';
$lang['acl_new']    = 'Adicionar nova entrada';

$lang['spell_start'] = 'Verificar erros de digitação';
$lang['spell_stop']  = 'Continuar editando';
$lang['spell_wait']  = 'Por favor, aguarde...';
$lang['spell_noerr'] = 'Nenhum erro encontrado';
$lang['spell_nosug'] = 'Sem sugestões';
$lang['spell_change']= 'Alterar';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/pt-br/lang.php <==
<?php
/**
 * Brazilian Portuguese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author    Luis Fernando Enciso <lfenciso@certto.com.br>
 * @author    Alauton/Loug
 */
$lang['encoding']     = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']     = 'Editar';
$lang['btn_source']   = 'Ver código fonte';
$lang['btn_show']     = 'Ver entrada';
$lang['btn_create']   = 'Criar entrada';
$lang['btn_search']   = 'Pesquisar';
$lang['btn_save']     = 'Salvar';
$lang['btn_preview']  = 'Pré-visualizar';
$lang['btn_top']      = 'Voltar ao topo';
$lang['btn_newer']  = '<< mais recente';
$lang['btn_older']  = 'menos recente >>';
$lang['btn_revs']     = 'Revisões';
$lang['btn_recent']   = 'Alterações recentes';
$lang['btn_upload']   = 'Upload';
$lang['btn_cancel']   = 'Cancelar';
$lang['btn_index']    = 'Índice';
$lang['btn_secedit']  = 'Editar';
$lang['btn_login']    = 'Login';
$lang['btn_logout']   = 'Sair';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Atualizar';
$lang['btn_delete'] = 'Deletar';
$lang['btn_back']   = 'Voltar';

$lang['loggedinas']   = 'Usuário';
$lang['user']         = 'Usuário';
$lang['pass']         = 'Senha';
$pass['passchk']    = 'novamente';
$lang['remember']     = 'Lembrar';
$lang['fullname']     = 'Nome completo';
$lang['email']        = 'E-mail';
$lang['register']     = 'Registrar-se';
$lang['badlogin']     = 'Nome de usuário ou senha inválida.';

$lang['regmissing']   = 'Por favor, preencha todos os campos.';
$lang['reguexists']   = 'Este usuário já está registrado. Por favor, escolha outro nome de usuário.';
$lang['regsuccess']   = 'O usuário foi criado. A senha será enviada para o e-mail usado na inscrição.';
$lang['regsuccess2']= 'O usuário foi criado.';
$lang['regmailfail']  = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
$lang['regbadmail']   = 'O endereço de e-mail é inválido. Se o endereço está correto, e isto é um erro, por favor, contacte o administrador!';
$lang['regbadpass'] = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
$lang['regpwmail']    = 'A sua senha DokuWiki';
$lang['reghere']      = 'Não tem uma conta? Para registrar-se, acesse';

$lang['txt_upload']   = 'Escolha o arquivo para upload';
$lang['txt_filename'] = 'Insira o nome wiki (opcional)';
$lang['txt_overwrt']  = 'Substituir arquivo existente';
$lang['lockedby']     = 'Atualmente bloqueado por';
$lang['lockexpire']   = 'O bloqueio expira em';
$lang['willexpire']   = 'O bloqueio de edição para este documento irá expirar num minuto.\nPara evitar conflitos de edição, clique no botão <Pré-visualização> para reiniciar o temporizador de bloqueio.';

$lang['notsavedyet']  = 'Existem alterações não gravadas, que serão perdidas se continuar.\nDeseja realmente continuar?';
$lang['rssfailed']    = 'Ocorreu um erro neste canal RSS: ';
$lang['nothingfound'] = 'Nada foi encontrado.';

$lang['mediaselect']  = 'Selecionar arquivos';
$lang['fileupload']   = 'Upload de arquivo';
$lang['uploadsucc']   = 'Upload feito com sucesso';
$lang['uploadfail']   = 'Falha no upload. Talvez por não ter permissões?';
$lang['uploadwrong']  = 'Upload negado. Esta extensão de arquivo está proibida.';
$lang['uploadexist'] = 'O arquivo já existe. Nada foi feito.';
$lang['namespaces']   = 'Prefixos';
$lang['mediafiles']   = 'Arquivos disponíveis em';

$lang['hits']         = 'Resultados';
$lang['quickhits']    = 'Entradas encontradas';
$lang['toc']          = 'Tabela de Conteúdos';
$lang['current']      = 'Atual';
$lang['yours']        = 'A sua versão';
$lang['diff']         = 'mostrar diferenças com a versão atual';
$lang['line']         = 'Linha';
$lang['breadcrumb']   = 'Visitou';
$lang['lastmod']      = 'Modificado em';
$lang['by']         = 'por';
$lang['deleted']      = 'removido';
$lang['created']      = 'criado';
$lang['restored']     = 'Versão anterior restaurada.';
$lang['summary']      = 'Sumário da Edição';

$lang['mail_newpage'] = 'página adicionada:';
$lang['mail_changed'] = 'página modificada:';

$lang['nosmblinks']   = 'Links para pastas Windows partilhadas apenas funcionam com o Microsoft Internet Explorer.\nPode, no entanto, copiar e colar o link.';

$lang['qb_alert']     = 'Por favor, insira o texto que deseja formatar.\nSerá acrescentado ao fim do documento.';
$lang['qb_bold']      = 'Negrito';
$lang['qb_italic']    = 'Itálico';
$lang['qb_underl']    = 'Sublinhado';
$lang['qb_code']      = 'Código';
$lang['qb_strike']  = 'Texto Riscado';
$lang['qb_h1']        = 'Cabeçalho Nível 1';
$lang['qb_h2']        = 'Cabeçalho Nível 2';
$lang['qb_h3']        = 'Cabeçalho Nível 3';
$lang['qb_h4']        = 'Cabeçalho Nível 4';
$lang['qb_h5']        = 'Cabeçalho Nível 5';
$lang['qb_link']      = 'Link Interno';
$lang['qb_extlink']   = 'Link Externo';
$lang['qb_hr']        = 'Barra Horizontal';
$lang['qb_ol']        = 'Item numa Lista Ordenada';
$lang['qb_ul']        = 'Item numa Lista Não Ordenada';
$lang['qb_media']     = 'Incluir imagens e/ou outros arquivos';
$lang['qb_sig']       = 'Inserir Assinatura';

$lang['del_confirm']= 'Deletar esta entrada?';
$lang['admin_register']= 'Adicionar novo usuário';

$lang['spell_start'] = 'Verificar erros de digitação';
$lang['spell_stop']  = 'Continuar editando';
$lang['spell_wait']  = 'Por favor, aguarde...';
$lang['spell_noerr'] = 'Nenhum erro encontrado';
$lang['spell_nosug'] = 'Sem sugestões';
$lang['spell_change']= 'Alterar';

//Setup VIM: ex: et ts=2 enc=utf-8 :
